==> ClanLib-1.0.0.tgz: ClanLib-1.0.0/Setup/Win32/page_system.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2005 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
*/

#ifndef header_page_system
#define header_page_system

class PageSystem
{
public:
	PageSystem();

	PROPSHEETPAGE propsheetpage;

	HPROPSHEETPAGE handle_propsheetpage;

	TCHAR path_input_include[MAX_PATH];

	TCHAR path_input_lib[MAX_PATH];

	static LRESULT CALLBACK dialog_proc(HWND, UINT, WPARAM, LPARAM);

	LRESULT on_notify(HWND hWnd, NMHDR *header);

	void on_input_lib_browse_clicked(HWND hWnd);

	void on_input_include_browse_clicked(HWND hWnd);

	static BOOL BrowseForFolder(HWND hOwner, TCHAR* szTitle, TCHAR* szRetval);
};

#endif

==> ClanLib-2.3.7.tgz: ClanLib-2.3.7/Setup/Win32/page_system.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2011 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
*/

#ifndef header_page_system
#define header_page_system

class PageSystem
{
public:
	PageSystem();

	PROPSHEETPAGE propsheetpage;
	HPROPSHEETPAGE handle_propsheetpage;
	TCHAR path_input_include[MAX_PATH];
	TCHAR path_input_lib[MAX_PATH];

	static INT_PTR CALLBACK dialog_proc(HWND, UINT, WPARAM, LPARAM);
	INT_PTR on_notify(HWND hWnd, NMHDR *header);
	void on_input_lib_browse_clicked(HWND hWnd);
	void on_input_include_browse_clicked(HWND hWnd);
	static BOOL BrowseForFolder(HWND hOwner, TCHAR* szTitle, TCHAR* szRetval);
};

#endif
